@@ -900,7 +900,7 @@ def visualize_fanio(fan_ins, fan_outs):
     mpl.rc('axes.spines', left=False, right=False, top=False, bottom = False)
     mpl.rc('figure', titlesize = 20, figsize = (20, 7))
 
-    fig1, fi_axes = plt.subplots(1, len(fan_ins))
+    fig1, fi_axes = plt.subplots(1, len(fan_ins)-1)
     fig2, fo_axes = plt.subplots(1, len(fan_outs))
 
     fig1.suptitle("Actiavation Dists")
